pilot.impl.pilotcompute_manager.PilotComputeService

Package pilot :: Package impl :: Module pilotcompute_manager :: Class PilotComputeService |

# Class PilotComputeService

source code

PilotComputeService (PCS).

Factory for PilotComputes..

Instance Methods
__init__(self, coordination_url=`'``redis://localhost``'`, pcs_url=None) Create a PilotJobService object. | source code
create_pilot(self, rm=None, pilot_compute_description=None, pj_type=None, context=None) Add a PilotJob to the PilotJobService | source code
list_pilots(self) List managed PilotComputes. | source code
cancel(self) Cancel the PilotComputeService. | source code
__repr__(self) repr(x) | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| PJS_ID_PREFIX = ``'``pcs-``'``

Properties
| id (Inherited from pilot.api.compute.api.PilotComputeService)
| pilot_jobs (Inherited from pilot.api.compute.api.PilotComputeService)
| state (Inherited from pilot.api.compute.api.PilotComputeService)
Inherited from `object`: `__class__`

Method Details

### __init__(self, coordination_url=`'``redis://localhost``'`, pcs_url=None) (Constructor) | source code
Create a PilotJobService object. Keyword arguments: pcs_id -- Don't create a new, but connect to an existing (optional) Overrides: object.__init__

### create_pilot(self, rm=None, pilot_compute_description=None, pj_type=None, context=None) | source code
Add a PilotJob to the PilotJobService Keyword arguments: pilot_compute_description -- PilotJob Description Return value: A PilotCompute object Overrides: api.compute.api.PilotComputeService.create_pilot

### list_pilots(self) | source code
List managed PilotComputes. Return value: A list of PilotCompute urls

### cancel(self) | source code
Cancel the PilotComputeService. This also cancels all the PilotJobs that were under control of this PJS. Keyword arguments: None Return value: Result of operation Overrides: api.compute.api.PilotComputeService.cancel

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)